
<li class="list-group-item dc-dropzone" title="Upload new document to {{ category.name }}"
    data-dc-category="{{ category.slug }}" data-url="{% url 'document_catalogue:api_post' category.slug %}">
    <span class="dz-message">Click or Drag-Drop here to upload files</span>
</li>
