<h4 class="'dc-document-title"><span class="value">{{ object }}</span></h4>

<dl class="dl-horizontal">
    <div class="dc-document-file">
        <dt>Download Link:</dt>
        <dd class="value"><a class="dc-document-download" href="{{ document.get_download_url }}">{{ view.get_document_absolute_uri }}</a></dd>
    </div>
    <div class="'dc-document-description">
        <dt>Description:</dt>
        <dd class="value">{{ object.description }}</dd>
    </div>
    <div class="'dc-document-creation">
        <dt>Created:</dt>
        <dd class="value">{{ object.creation_date }}</dd>
    </div>
    <div class="'dc-document-update">
        <dt>Last Modified:</dt>
        <dd class="value">{{ object.update_date }}</dd>
    </div>
</dl>