{% if document_list %}
    {% for document in document_list %}
        <li class="dc-document-item list-group-item">
            <div class="media">
                <div class="media-left media-middle">
                    <a class="dc-document-download media-object large" href="{{ document.get_download_url }}" title="Download File">
                        <span class="glyphicon glyphicon-save-file"></span>
                    </a>
                </div>
                <div class="media-body media-middle">
                    <a class="dc-document-download" href="{{ document.get_absolute_url }}" title="View Document Details">
                        <h5 class="media-heading">{{ document.title }}</h5>
                    </a>
                    {% if document.description %}
                        <span><small>{{ document.description }}</small></span>
                    {% endif %}
                </div>
                <div class="media-right media-middle">
                    <span class="dc-document-actions media-object">
                        {% if user_can_edit_document %}
                            <a class="btn dc-document-edit" href="{{ document.get_edit_url }}" title="Edit Document Details">
                                <span class="text-default glyphicon glyphicon-edit" aria-hidden="true"></span>
                                <span class="sr-only">Edit</span>
                            </a>
                        {% endif %}
                        <a class="btn dc-document-link" href="{{ document.get_absolute_url }}" title="View Document Details">
                            <span class="glyphicon glyphicon-option-vertical" aria-hidden="true"></span>
                            <span class="sr-only">Details</span>
                        </a>
                    </span>
                </div>
            </div>
        </li>
    {% endfor %}
{% endif %}
