{% extends 'document_catalogue/base.html' %}

{% block dc-content %}

    {% include 'document_catalogue/include/breadcrumb.html' with current_category_link=True %}

    <div class="dc-document-detail container-fluid">
        {% include 'document_catalogue/include/document.html' %}
    </div>

    {% if show_edit_links and user_can_edit_document %}
        <div class="dc-document-actions">
            <a class="dc-document-edit-link btn btn-primary" href="{% url 'document_catalogue:document_edit' document.pk %}" role="button">
                <span class="glyphicon glyphicon-edit" aria-hidden="true"></span> Edit
            </a>
        </div>
    {% endif %}

{% endblock %}
